@@ -578,7 +578,7 @@ function [Q,M] = q_planet_local(Q,A,workfolder,do_atten,do_faraday, ...
     Q.REFR_INDEX_AIR_AGENDA = { 
         'NumericSet( refr_index_air, 1.0 )', ...
         'NumericSet( refr_index_air_group, 1.0 )',...
-        'refr_index_airThayer', ...
+        'refr_index_airMicrowavesEarth', ...
         'refr_index_airFreeElectrons( demand_vmr_value = 0 )' };
     %
    otherwise 
