@@ -91,24 +91,23 @@ Q.ABS_SPECIES(4).TAG{2} = 'H2O-PWR98';
 Q.ABS_SPECIES(5).TAG{1} = 'N2-SelfContStandardType';
 %
 Q.ABSORPTION            = 'OnTheFly';  % A simple, but slow, option!
-Q.ABS_LINES_FORMAT      = 'Arts';
+Q.ABS_LINES_FORMAT      = 'ARTSCAT';
 Q.ABS_LINES             = fullfile( atmlab_example_data , 'lines501.4' );
-Q.ABS_LINESHAPE         = 'Voigt_Kuntz6';
+Q.ABS_LINESHAPE         = 'VP';
 Q.ABS_LINESHAPE_CUTOFF  = -1;
 Q.ABS_LINESHAPE_FACTOR  = 'VVH';
 
 
 %= Set RTE variables (refraction is here neglected)
 %
-Q.IY_MAIN_AGENDA        = { 'iyEmissionStandard' };
-Q.BLACKBODY_RADIATION_AGENDA = { 'blackbody_radiationPlanck' };
+Q.IY_MAIN_AGENDA        = { 'ppathCalc', 'iyEmissionStandard' };
 Q.IY_SPACE_AGENDA       = { 'Ignore(rtp_pos)', 'Ignore(rtp_los)', ...
                             'MatrixCBR(iy,stokes_dim,f_grid)' };
 Q.SURFACE_RTPROP_AGENDA = { 'Ignore(rtp_pos)', 'Ignore(rtp_los)', ...
                            ['InterpAtmFieldToPosition(out=surface_skin_t,', ...
                                                          'field=t_field)'], ...
                             'surfaceBlackbody' };
-Q.IY_SURFACE_AGENDA     = { 'iySurfaceRtpropAgenda' };
+Q.IY_SURFACE_AGENDA     = { 'SurfaceDummy', 'iySurfaceRtpropAgenda' };
 Q.IY_AUX_VARS           = [];
 %
 Q.YCALC_WSMS            = { 'yCalc' };
