@@ -1,4 +1,4 @@
-function commands = psbox(file,in,commands)
+function box = psbox(file,in)
 % PSBOX Makes boxes in gmtplot
 %
 % IN      file     %s       file to append to
@@ -8,7 +8,7 @@ function commands = psbox(file,in,commands)
 % OUT     command  cell     cell of string commands for systemcall
 %
 % Created by Salomon Eliasson
-% $Id: psbox.m 8362 2013-04-20 18:30:35Z seliasson $
+% $Id: psbox.m 9251 2015-03-23 20:09:59Z seliasson $
 
 colors = in.plot.psbox.colors;
 thick = in.plot.psbox.thick;
@@ -33,7 +33,7 @@ for i = 1:size(pb,1)
 
     stdin=[a{1},' M\n',a{2},' D\n',a{3},' D\n',a{4},' D\n',a{5},' D\n',a{6},' D\n',a{7},' D'];
     box = sprintf('echo -e "%s" |',stdin);
-    box = sprintf('%s psxy -R%s -J%s -A',box,region,proj);
+    box = sprintf('%s gmt psxy -R%s -J%s -A',box,region,proj);
     box = sprintf('%s %s',box,in.plotPlacement);
     
     % color and size of box
@@ -44,5 +44,4 @@ for i = 1:size(pb,1)
     
     % selects Overlay plot mode and assume more pscode will be appended later
     box = sprintf('%s -K -O >> %s.ps',box,file);
-    commands{end+1} = box;
 end
