@@ -17,7 +17,7 @@ function y = yearnum(varargin)
 %   URL:         http://home.online.no/~pjacklam
 
    nargsin = nargin;
-   error(nargchk(0, 6, nargsin));
+   %error(nargchk(0, 6, nargsin));
    if nargsin
       argv = {1 1 1 0 0 0};
       argv(1:nargsin) = varargin;
